@@ -56,9 +56,9 @@ def _transform_inputs_and_outputs(k_model: Model) -> Model:
         new_input_shape = Permute(
             calculate_permute_values(k_input.shape, to_channel_first=False))(k_input).shape[1:]
         if k_input.shape[0] is None:
-            new_input_tensor = tf.keras.Input(new_input_shape)
+            new_input_tensor = tf.keras.Input(new_input_shape, name=k_input.name)
         else:
-            new_input_tensor = tf.keras.Input(new_input_shape, batch_size=k_input.shape[0])
+            new_input_tensor = tf.keras.Input(new_input_shape, name=k_input.name, batch_size=k_input.shape[0])
         back_to_channel_first_perm_values = calculate_permute_values(new_input_tensor.shape, to_channel_first=True)
         permute_after = Permute(back_to_channel_first_perm_values)(new_input_tensor)
         new_inputs.append(new_input_tensor)
