@@ -74,6 +74,9 @@ class ModelConverter:
             if isinstance(arg, dict):
                 new_arg_dict, node_input_tensors = self._fix_kwargs(arg, node_input_tensors)
                 new_tfoplambda_args[i] = new_arg_dict
+            if isinstance(arg, list):
+                new_arg, node_input_tensors = self._fix_args(arg, node_input_tensors)
+                new_tfoplambda_args[i] = new_arg
             elif isinstance(arg, KerasTensor):
                 try:
                     tensor_index = self._find_tensor_index_by_name(node_input_tensors, arg.name)
@@ -85,7 +88,13 @@ class ModelConverter:
     def _fix_kwargs(self, call_kwargs, node_input_tensors):
         new_tfoplambda_kwargs = call_kwargs.copy()
         for key, arg in call_kwargs.items():
-            if isinstance(arg, KerasTensor):
+            if isinstance(arg, dict):
+                new_arg_dict, node_input_tensors = self._fix_kwargs(arg, node_input_tensors)
+                new_tfoplambda_kwargs[key] = new_arg_dict
+            elif isinstance(arg, list):
+                new_arg, node_input_tensors = self._fix_args(arg, node_input_tensors)
+                new_tfoplambda_kwargs[key] = new_arg
+            elif isinstance(arg, KerasTensor):
                 try:
                     tensor_index = self._find_tensor_index_by_name(node_input_tensors, arg.name)
                     new_tfoplambda_kwargs[key] = node_input_tensors.pop(tensor_index)
@@ -108,17 +117,9 @@ class ModelConverter:
 
         call_args = current_layer.inbound_nodes[0].call_args
         call_kwargs = current_layer.inbound_nodes[0].call_kwargs
-        if isinstance(current_layer, TFOpLambda) and current_layer.symbol == 'stack':
-            return converted_layer(node_input_tensors, *current_layer.inbound_nodes[0].call_args[2:],
-                                   **current_layer.inbound_nodes[0].call_kwargs)
-
         if not isinstance(node_input_tensors, list):
             node_input_tensors = [node_input_tensors]
 
-        if isinstance(current_layer, TFOpLambda) and current_layer.symbol == 'concat':
-            # default call expects [list_of_values] while for concat it is [[list_of_values]]
-            call_args = [self._fix_args(call_args[0], node_input_tensors)[0]]
-
         return self._default_call_layer_by_args(converted_layer, call_args, call_kwargs, node_input_tensors)
 
     def _convert_tensor(self, tensor: tf.Tensor) -> tf.Tensor:
